@@ -1,8 +1,10 @@
+import re
 import threading
 from typing import Optional
 
 import requests
 
+from . import __version__
 from .backend.mprm import Mprm
 from .devices.gateway import Gateway
 from .devices.zwave import (Zwave, get_device_type_from_element_uid,
@@ -15,8 +17,8 @@ from .properties.dewpoint_sensor_property import DewpointSensorProperty
 from .properties.humidity_bar_property import HumidityBarProperty
 from .properties.mildew_sensor_property import MildewSensorProperty
 from .properties.multi_level_sensor_property import MultiLevelSensorProperty
+from .properties.multi_level_switch_property import MultiLevelSwitchProperty
 from .properties.settings_property import SettingsProperty
-from .properties.voltage_property import VoltageProperty
 from .publisher.publisher import Publisher
 from .publisher.updater import Updater
 
@@ -32,6 +34,7 @@ class HomeControl(Mprm):
 
     def __init__(self, gateway_id: str, url: str = "https://homecontrol.mydevolo.com"):
         self._session = requests.Session()
+        self._session.headers.update({"User-Agent": f"devolo_home_control_api/{__version__}"})
         self._session.url = url
 
         self.gateway = Gateway(gateway_id)
@@ -41,7 +44,8 @@ class HomeControl(Mprm):
         self.devices = {}
         self._inspect_devices(self.get_all_devices())
 
-        self.device_names = dict(zip([self.devices.get(device).itemName for device in self.devices],
+        self.device_names = dict(zip([(self.devices.get(device).itemName + "/" + self.devices.get(device).zone)
+                                      for device in self.devices],
                                      [self.devices.get(device).uid for device in self.devices]))
 
         self.publisher = Publisher([device for device in self.devices])
@@ -63,6 +67,24 @@ class HomeControl(Mprm):
         """ Get all binary switch devices. """
         return [self.devices.get(uid) for uid in self.devices if hasattr(self.devices.get(uid), "binary_switch_property")]
 
+    @property
+    def blinds_devices(self) -> list:
+        """ Get all blinds devices. """
+        blinds_devices = []
+        [[blinds_devices.append(device) for multi_level_switch_property in device.multi_level_switch_property
+          if multi_level_switch_property.startswith("devolo.Blinds")] for device in self.multi_level_switch_devices]
+        return blinds_devices
+
+    @property
+    def multi_level_sensor_devices(self) -> list:
+        """ Get all multi level sensor devices. """
+        return [self.devices.get(uid) for uid in self.devices if hasattr(self.devices.get(uid), "multi_level_sensor_property")]
+
+    @property
+    def multi_level_switch_devices(self) -> list:
+        """ Get all multi level switch devices. This also includes blinds devices. """
+        return [self.devices.get(uid) for uid in self.devices if hasattr(self.devices.get(uid), "multi_level_switch_property")]
+
 
     def device_change(self, device_uids: list):
         """
@@ -180,14 +202,21 @@ class HomeControl(Mprm):
 
         elements = {"devolo.BinarySensor": self._binary_sensor,
                     "devolo.BinarySwitch": self._binary_switch,
+                    "devolo.Blinds": self._multi_level_switch,
                     "devolo.DewpointSensor": self._dewpoint,
+                    "devolo.Dimmer": self._multi_level_switch,
                     "devolo.HumidityBarValue": self._humidity_bar,
                     "devolo.HumidityBarZone": self._humidity_bar,
                     "devolo.LastActivity": self._last_activity,
                     "devolo.Meter": self._meter,
                     "devolo.MildewSensor": self._mildew,
                     "devolo.MultiLevelSensor": self._multi_level_sensor,
-                    "devolo.VoltageMultiLevelSensor": self._voltage_multi_level_sensor,
+                    "devolo.MultiLevelSwitch": self._multi_level_switch,
+                    "devolo.SirenBinarySensor": self._binary_sensor,
+                    "devolo.SirenMultiLevelSensor": self._multi_level_sensor,
+                    "devolo.SirenMultiLevelSwitch": self._multi_level_switch,
+                    "devolo.VoltageMultiLevelSensor": self._multi_level_sensor,
+                    "bas.hdm": self._binary_async,
                     "lis.hdm": self._led,
                     "gds.hdm": self._general_device,
                     "cps.hdm": self._parameter,
@@ -209,17 +238,38 @@ class HomeControl(Mprm):
             if uid_info.get("UID") is not None:
                 elements.get(get_device_type_from_element_uid(uid_info.get("UID")), self._unknown)(uid_info)
 
+    def _binary_async(self, uid_info: dict):
+        """ Process binary async setting (bas) properties. """
+        device_uid = get_device_uid_from_setting_uid(uid_info.get("UID"))
+        self._logger.debug(f"Adding binary async settings to {device_uid}.")
+        settings_property = SettingsProperty(session=self._session,
+                                             gateway=self.gateway,
+                                             element_uid=uid_info.get("UID"),
+                                             value=uid_info.get("properties").get("value"))
+
+        # The siren needs to be handled differently, as otherwise their binary async setting will not be named nicely
+        if self.devices.get(device_uid).deviceModelUID == "devolo.model.Siren":
+            self.devices[device_uid].settings_property["muted"] = settings_property
+        # As some devices have multiple binary async settings, we use the settings UID split after a '#' as key
+        else:
+            key = camel_case_to_snake_case(uid_info.get("UID").split("#")[-1])
+            self.devices[device_uid].settings_property[key] = settings_property
+
     def _last_activity(self, uid_info: dict):
         """
         Process last activity properties. Those don't go into an own property but will be appended to a parent property.
         This parent property is found by string replacement.
         """
         device_uid = get_device_uid_from_element_uid(uid_info.get("UID"))
-        if uid_info.get("properties").get("lastActivityTime") != -1 and \
-                hasattr(self.devices[device_uid], "binary_sensor_property"):
+        if hasattr(self.devices[device_uid], "binary_sensor_property"):
             parent_element_uid = uid_info.get("UID").replace("LastActivity", "BinarySensor")
-            self.devices[device_uid].binary_sensor_property[parent_element_uid].last_activity = \
-                uid_info.get("properties").get("lastActivityTime")
+            if self.devices[device_uid].binary_sensor_property.get(parent_element_uid) is not None:
+                self.devices[device_uid].binary_sensor_property[parent_element_uid].last_activity = \
+                    uid_info.get("properties").get("lastActivityTime")
+            parent_element_uid = uid_info.get("UID").replace("LastActivity", "SirenBinarySensor")
+            if self.devices[device_uid].binary_sensor_property.get(parent_element_uid) is not None:
+                self.devices[device_uid].binary_sensor_property[parent_element_uid].last_activity = \
+                    uid_info.get("properties").get("lastActivityTime")
 
     def _led(self, uid_info: dict):
         """ Process LED information setting (lis) and visual feedback setting (vfs) properties. """
@@ -278,7 +328,7 @@ class HomeControl(Mprm):
         device_uid = get_device_uid_from_element_uid(uid_info.get("UID"))
         if not hasattr(self.devices[device_uid], "multi_level_sensor_property"):
             self.devices[device_uid].multi_level_sensor_property = {}
-        self._logger.debug(f"Adding multi_level_sensor property {uid_info.get('UID')} to {device_uid}.")
+        self._logger.debug(f"Adding multi level sensor property {uid_info.get('UID')} to {device_uid}.")
         self.devices[device_uid].multi_level_sensor_property[uid_info.get("UID")] = \
             MultiLevelSensorProperty(session=self._session,
                                      gateway=self.gateway,
@@ -287,6 +337,21 @@ class HomeControl(Mprm):
                                      unit=uid_info.get("properties").get("unit"),
                                      sensor_type=uid_info.get("properties").get("sensorType"))
 
+    def _multi_level_switch(self, uid_info: dict):
+        """ Process multi level switch properties. """
+        device_uid = get_device_uid_from_element_uid(uid_info.get("UID"))
+        if not hasattr(self.devices[device_uid], "multi_level_switch_property"):
+            self.devices[device_uid].multi_level_switch_property = {}
+        self._logger.debug(f"Adding multi level switch property {uid_info.get('UID')} to {device_uid}.")
+        self.devices[device_uid].multi_level_switch_property[uid_info.get("UID")] = \
+            MultiLevelSwitchProperty(session=self._session,
+                                     gateway=self.gateway,
+                                     element_uid=uid_info.get("UID"),
+                                     value=uid_info.get("properties").get("value"),
+                                     switch_type=uid_info.get("properties").get("switchType"),
+                                     max=uid_info.get("properties").get("max"),
+                                     min=uid_info.get("properties").get("min"))
+
     def _parameter(self, uid_info: dict):
         """ Process custom parameter setting (cps) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info.get("UID"))
@@ -323,18 +388,15 @@ class HomeControl(Mprm):
         """ Ignore unknown properties. """
         self._logger.debug(f"Found an unexpected element uid: {uid_info.get('UID')}")
 
-    def _voltage_multi_level_sensor(self, uid_info: dict):
-        """ Process VoltageMultiLevelSensor properties. """
-        device_uid = get_device_uid_from_element_uid(uid_info.get("UID"))
-        if not hasattr(self.devices[device_uid], "voltage_property"):
-            self.devices[device_uid].voltage_property = {}
-        self._logger.debug(f"Adding voltage property to {device_uid}.")
-        self.devices[device_uid].voltage_property[uid_info.get("UID")] = \
-            VoltageProperty(session=self._session,
-                            gateway=self.gateway,
-                            element_uid=uid_info.get("UID"),
-                            current=uid_info.get("properties").get("value"),
-                            sensor_type=uid_info.get("properties").get("sensorType"))
+
+def camel_case_to_snake_case(expression: str) -> str:
+    """
+    Turn CamelCaseStrings to snake_case_strings. This is used where the original Java names should by more pythonic.
+
+    :param: expression: Expression, that should be converted to snake case
+    :return: Expression in snake case
+    """
+    return re.sub(r'(?<!^)(?=[A-Z])', '_', expression).lower()
 
 
 def get_sub_device_uid_from_element_uid(element_uid: str) -> Optional[int]:
