@@ -109,13 +109,6 @@ class TestMydevolo:
             mydevolo._call("test")
         Mydevolo.del_instance()
 
-    @pytest.mark.usefixtures("mock_mydevolo__call_raise_GatewayOfflineError")
-    def test_call_GatewayOfflineError(self):
-        mydevolo = Mydevolo()
-        with pytest.raises(GatewayOfflineError):
-            mydevolo._call("test")
-        Mydevolo.del_instance()
-
     @pytest.mark.usefixtures("mock_response_gateway_offline")
     def test_call_GatewayOfflineError(self, mydevolo):
         with pytest.raises(GatewayOfflineError):
